@@ -177,6 +177,13 @@ impl Configuration {
                     });
                 }
 
+                // Used by Gremlin return format to return the label itself
+                if t.props.iter().any(|p| p.name().to_uppercase() == "LABEL") {
+                    return Err(Error::ConfigItemReserved {
+                        type_name: "label".to_string(),
+                    });
+                }
+
                 if t.rels
                     .iter()
                     .any(|r| r.props.iter().any(|p| p.name().to_uppercase() == "ID"))
@@ -186,6 +193,34 @@ impl Configuration {
                     });
                 }
 
+                // Used by Gremlin return format to return the label itself
+                if t.rels
+                    .iter()
+                    .any(|r| r.props.iter().any(|p| p.name().to_uppercase() == "LABEL"))
+                {
+                    return Err(Error::ConfigItemReserved {
+                        type_name: "label".to_string(),
+                    });
+                }
+
+                if t.rels
+                    .iter()
+                    .any(|r| r.props.iter().any(|p| p.name().to_uppercase() == "SRC"))
+                {
+                    return Err(Error::ConfigItemReserved {
+                        type_name: "src".to_string(),
+                    });
+                }
+
+                if t.rels
+                    .iter()
+                    .any(|r| r.props.iter().any(|p| p.name().to_uppercase() == "DST"))
+                {
+                    return Err(Error::ConfigItemReserved {
+                        type_name: "dst".to_string(),
+                    });
+                }
+
                 t.rels.iter().try_for_each(|r| {
                     let rel_name_variants = rel_name_variants(t, r);
 
@@ -774,7 +809,7 @@ pub struct Property {
 
     /// True if this property is required to be present on this type; false if the property is
     /// optional
-    #[serde(default = "get_false")]
+    #[serde(default = "get_true")]
     required: bool,
 
     /// True if this property is a list
@@ -1154,7 +1189,7 @@ impl Relationship {
 #[derive(Clone, Debug, Deserialize, Eq, Hash, Ord, PartialEq, PartialOrd, Serialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Type {
-    /// Name of this GraphQL type, also used as the Neo4J label for nodes
+    /// Name of this GraphQL type, also used as the label for nodes
     name: String,
 
     /// Vector of properties on this type
@@ -2188,6 +2223,42 @@ mod tests {
         }
     }
 
+    #[allow(clippy::match_wild_err_arm)]
+    #[test]
+    fn config_prop_name_src_test() {
+        let rel_prop_name_src_config: Configuration =
+            match File::open("tests/fixtures/config-validation/test_config_rel_prop_name_src.yml")
+                .expect("Couldn't open file")
+                .try_into()
+            {
+                Err(e) => panic!("{}", e),
+                Ok(wgc) => wgc,
+            };
+
+        match rel_prop_name_src_config.validate() {
+            Err(Error::ConfigItemReserved { type_name: _ }) => (),
+            _ => panic!(),
+        }
+    }
+
+    #[allow(clippy::match_wild_err_arm)]
+    #[test]
+    fn config_prop_name_dst_test() {
+        let rel_prop_name_dst_config: Configuration =
+            match File::open("tests/fixtures/config-validation/test_config_rel_prop_name_dst.yml")
+                .expect("Couldn't open file")
+                .try_into()
+            {
+                Err(e) => panic!("{}", e),
+                Ok(wgc) => wgc,
+            };
+
+        match rel_prop_name_dst_config.validate() {
+            Err(Error::ConfigItemReserved { type_name: _ }) => (),
+            _ => panic!(),
+        }
+    }
+
     #[allow(clippy::match_wild_err_arm)]
     #[test]
     fn config_scalar_name_int_test() {
