@@ -12,11 +12,11 @@
 //!
 //! To browse source code, report issues, or contribute to the project, see the [GitHub Repository](https://github.com/warpforge/warpgrapher).
 
-#![doc(html_root_url = "https://docs.rs/warpgrapher/0.9.1")]
+#![doc(html_root_url = "https://docs.rs/warpgrapher/0.10.1")]
 
-#[cfg(feature = "neo4j")]
+#[cfg(feature = "cypher")]
 pub use bolt_client;
-#[cfg(feature = "neo4j")]
+#[cfg(feature = "cypher")]
 pub use bolt_proto;
 #[cfg(feature = "gremlin")]
 pub use gremlin_client;
